# Release Notes

## Version History

### 1.1.1

- Mirror packages to pypi

### 1.1.0

- Provide ADTF File Python Module (integrated and extracted from ADTF File Library)
- Deploy binary packages for common python versions and platforms

### 1.0.0

- Initial release
- Provide ADTF Python Module
- Requires at least ADTF 3.21

## Known Issues / Restrictions

- `item_count` for the reader in the adtf_file module is disabled (Due to a ABI incopatibility regarding `std::optional` between GCC 7 and any GCC >= 8)
